==> com.liferay.headless.commerce.admin.catalog.impl-4.0.88-sources-commercial.jar: com/liferay/headless/commerce/admin/catalog/internal/jaxrs/exception/mapper/AttachmentSizeExceptionMapper.java <==
/**
 * Copyright (c) 2000-present Liferay, Inc. All rights reserved.
 *
 * The contents of this file are subject to the terms of the Liferay Enterprise
 * Subscription License ("License"). You may not use this file except in
 * compliance with the License. You can obtain a copy of the License by
 * contacting Liferay, Inc. See the License for the specific language governing
 * permissions and limitations under the License, including but not limited to
 * distribution rights of the Software.
 *
 *
 *
 */

package com.liferay.headless.commerce.admin.catalog.internal.jaxrs.exception.mapper;

import com.liferay.commerce.product.exception.CPAttachmentFileEntrySizeException;
import com.liferay.portal.vulcan.jaxrs.exception.mapper.BaseExceptionMapper;
import com.liferay.portal.vulcan.jaxrs.exception.mapper.Problem;

import javax.ws.rs.core.Response;
import javax.ws.rs.ext.ExceptionMapper;
import javax.ws.rs.ext.Provider;

import org.osgi.service.component.annotations.Component;

/**
 * @author Alessio Antonio Rendina
 * @author Zoltán Takács
 */
@Component(
	property = {
		"osgi.jaxrs.application.select=(osgi.jaxrs.name=Liferay.Headless.Commerce.Admin.Catalog)",
		"osgi.jaxrs.extension=true",
		"osgi.jaxrs.name=Liferay.Headless.Commerce.Admin.Catalog.AttachmentSizeExceptionMapper"
	},
	service = ExceptionMapper.class
)
@Provider
public class AttachmentSizeExceptionMapper
	extends BaseExceptionMapper<CPAttachmentFileEntrySizeException> {

	@Override
	protected Problem getProblem(
		CPAttachmentFileEntrySizeException cpAttachmentFileEntrySizeException) {

		return new Problem(
			Response.Status.BAD_REQUEST,
			cpAttachmentFileEntrySizeException.getMessage());
	}

}

==> com.liferay.headless.commerce.admin.catalog.impl-4.0.92-sources-commercial.jar: com/liferay/headless/commerce/admin/catalog/internal/jaxrs/exception/mapper/AttachmentSizeExceptionMapper.java <==
/**
 * Copyright (c) 2000-present Liferay, Inc. All rights reserved.
 *
 * The contents of this file are subject to the terms of the Liferay Enterprise
 * Subscription License ("License"). You may not use this file except in
 * compliance with the License. You can obtain a copy of the License by
 * contacting Liferay, Inc. See the License for the specific language governing
 * permissions and limitations under the License, including but not limited to
 * distribution rights of the Software.
 *
 *
 *
 */

package com.liferay.headless.commerce.admin.catalog.internal.jaxrs.exception.mapper;

import com.liferay.commerce.product.exception.CPAttachmentFileEntrySizeException;
import com.liferay.portal.vulcan.jaxrs.exception.mapper.BaseExceptionMapper;
import com.liferay.portal.vulcan.jaxrs.exception.mapper.Problem;

import javax.ws.rs.ext.ExceptionMapper;
import javax.ws.rs.ext.Provider;

import org.osgi.service.component.annotations.Component;

/**
 * @author Alessio Antonio Rendina
 * @author Zoltán Takács
 */
@Component(
	property = {
		"osgi.jaxrs.application.select=(osgi.jaxrs.name=Liferay.Headless.Commerce.Admin.Catalog)",
		"osgi.jaxrs.extension=true",
		"osgi.jaxrs.name=Liferay.Headless.Commerce.Admin.Catalog.AttachmentSizeExceptionMapper"
	},
	service = ExceptionMapper.class
)
@Provider
public class AttachmentSizeExceptionMapper
	extends BaseExceptionMapper<CPAttachmentFileEntrySizeException> {

	@Override
	protected Problem getProblem(
		CPAttachmentFileEntrySizeException cpAttachmentFileEntrySizeException) {

		return new Problem(cpAttachmentFileEntrySizeException);
	}

}
